xclim.testing.tests package
===========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xclim.testing.tests.test_sdba

Submodules
----------

xclim.testing.tests.conftest module
-----------------------------------

.. automodule:: xclim.testing.tests.conftest
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.data module
-------------------------------

.. automodule:: xclim.testing.tests.data
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_analog module
---------------------------------------

.. automodule:: xclim.testing.tests.test_analog
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_atmos module
--------------------------------------

.. automodule:: xclim.testing.tests.test_atmos
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_calendar module
-----------------------------------------

.. automodule:: xclim.testing.tests.test_calendar
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_checks module
---------------------------------------

.. automodule:: xclim.testing.tests.test_checks
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_cli module
------------------------------------

.. automodule:: xclim.testing.tests.test_cli
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_ensembles module
------------------------------------------

.. automodule:: xclim.testing.tests.test_ensembles
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_formatting module
-------------------------------------------

.. automodule:: xclim.testing.tests.test_formatting
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_fwi module
------------------------------------

.. automodule:: xclim.testing.tests.test_fwi
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_generic module
----------------------------------------

.. automodule:: xclim.testing.tests.test_generic
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_hydrology module
------------------------------------------

.. automodule:: xclim.testing.tests.test_hydrology
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_indicators module
-------------------------------------------

.. automodule:: xclim.testing.tests.test_indicators
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_indices module
----------------------------------------

.. automodule:: xclim.testing.tests.test_indices
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_land module
-------------------------------------

.. automodule:: xclim.testing.tests.test_land
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_locales module
----------------------------------------

.. automodule:: xclim.testing.tests.test_locales
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_missing module
----------------------------------------

.. automodule:: xclim.testing.tests.test_missing
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_modules module
----------------------------------------

.. automodule:: xclim.testing.tests.test_modules
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_options module
----------------------------------------

.. automodule:: xclim.testing.tests.test_options
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_precip module
---------------------------------------

.. automodule:: xclim.testing.tests.test_precip
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_run\_length module
--------------------------------------------

.. automodule:: xclim.testing.tests.test_run_length
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_seaice module
---------------------------------------

.. automodule:: xclim.testing.tests.test_seaice
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_stats module
--------------------------------------

.. automodule:: xclim.testing.tests.test_stats
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_subset module
---------------------------------------

.. automodule:: xclim.testing.tests.test_subset
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_temperature module
--------------------------------------------

.. automodule:: xclim.testing.tests.test_temperature
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_units module
--------------------------------------

.. automodule:: xclim.testing.tests.test_units
   :members:
   :undoc-members:
   :show-inheritance:

xclim.testing.tests.test\_utils module
--------------------------------------

.. automodule:: xclim.testing.tests.test_utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: xclim.testing.tests
   :members:
   :undoc-members:
   :show-inheritance:
